@@ -1,16 +1,7 @@
-let print_loc ppf loc =
-  Location.print_loc ppf loc
-
-
-let print_error loc f ppf x =
+let print_error ~loc ~f ppf x =
 #if OCAML_VERSION >= (5,3,0)
   let error =
-    let f (fmt: Format_doc.formatter) err =
-      let doc_f =
-        Format_doc.deprecated_printer (fun fmt -> Format.fprintf fmt "%a" f err)
-      in
-      doc_f fmt
-    in
+    let f = Format_doc.deprecated f in
     Location.error_of_printer ~loc f x in
   Location.print_report ppf error
 #elif OCAML_VERSION >= (4,8,0)
@@ -231,7 +222,7 @@ module String = struct
 
   module B = struct
     include Bytes
-    let for_all p s =
+    let for_all ~f:p s =
       let n = length s in
       let rec loop i =
         if i = n then true
@@ -242,8 +233,8 @@ module String = struct
 
   let bos = B.unsafe_of_string
 
-  let for_all f s =
-    B.for_all f (bos s)
+  let for_all ~f s =
+    B.for_all ~f (bos s)
 
   let get_utf_8_uchar s i = B.get_utf_8_uchar (bos s) i
   let is_valid_utf_8 s = B.is_valid_utf_8 (bos s)
@@ -275,7 +266,7 @@ module Utf8_lexeme = struct
 
   let _ =
     List.iter
-      (fun (upper, lower) ->
+      ~f:(fun (upper, lower) ->
         let upper = Uchar.of_int upper and lower = Uchar.of_int lower in
         Hashtbl.add known_chars upper (Upper lower);
         Hashtbl.add known_chars lower (Lower upper))
@@ -306,7 +297,7 @@ module Utf8_lexeme = struct
 
   let _ =
     List.iter
-      (fun (c1, n2, n) ->
+      ~f:(fun (c1, n2, n) ->
         Hashtbl.add known_pairs
           (Uchar.of_char c1, Uchar.of_int n2) (Uchar.of_int n))
   [
@@ -360,7 +351,7 @@ module Utf8_lexeme = struct
       end in
     let ascii_limit = 128 in
     if s = ""
-    || keep_ascii && String.for_all (fun x -> Char.code x < ascii_limit) s
+    || keep_ascii && String.for_all ~f:(fun x -> Char.code x < ascii_limit) s
     then Ok s
     else
       let buf = Buffer.create (String.length s) in
@@ -390,36 +381,6 @@ module Utf8_lexeme = struct
       | Some(Upper _) -> true
       | _ -> false
 
-  let uchar_lowercase u =
-    let c = Uchar.to_int u in
-    if c < 0x80 then
-      if c >= 65 && c <= 90 then Uchar.of_int (c + 32) else u
-    else
-      match Hashtbl.find_opt known_chars u with
-      | Some(Upper u') -> u'
-      | _ -> u
-
-  let uchar_uppercase u =
-    let c = Uchar.to_int u in
-    if c < 0x80 then
-      if c >= 97 && c <= 122 then Uchar.of_int (c - 32) else u
-    else
-      match Hashtbl.find_opt known_chars u with
-      | Some(Lower u') -> u'
-      | _ -> u
-
-  let capitalize s =
-    let first = ref true in
-    normalize_generic ~keep_ascii:false
-      (fun u -> if !first then (first := false; uchar_uppercase u) else u)
-      s
-
-  let uncapitalize s =
-    let first = ref true in
-    normalize_generic ~keep_ascii:false
-      (fun u -> if !first then (first := false; uchar_lowercase u) else u)
-      s
-
   let is_capitalized s =
     s <> "" &&
     uchar_is_uppercase (Uchar.utf_decode_uchar (String.get_utf_8_uchar s 0))
@@ -473,12 +434,6 @@ module Utf8_lexeme = struct
   let is_valid_identifier s =
     validate_identifier s = Valid
 
-  let starts_like_a_valid_identifier s =
-    s <> "" &&
-    (let u = Uchar.utf_decode_uchar (String.get_utf_8_uchar s 0) in
-     uchar_valid_in_identifier ~with_dot:false u
-     && not (uchar_not_identifier_start u))
-
   let is_lowercase s =
     let rec is_lowercase_at len s n =
       if n >= len then true
